@@ -251,18 +251,6 @@ public:
 class __EXPORT Engine
 {
 public:
-	/**
-	 * If problems happen which are fatal - expect one of these thrown 
-	 * at you
-	 */
-#ifdef	CCXX_EXCEPTIONS
-	class Exception : public PersistException
-	{
-	public:
-		Exception(const String &reason);
-	};
-#endif
-	
 	/**
 	 * These are the modes the Persistence::Engine can work in
 	 */
@@ -293,36 +281,36 @@ public:
 	/**
 	 * writes a BaseObject from a reference.
 	 */
-	void write(const BaseObject &object) THROWS (Exception)
+	void write(const BaseObject &object) THROWS (PersistException)
 	{ write(&object); };
 
 	/**
 	 * writes a BaseObject from a pointer.
 	 */
-	void write(const BaseObject *object) THROWS (Exception);
+	void write(const BaseObject *object) THROWS (PersistException);
 
 	// writes supported primitive types
   // shortcut, to make the following more readable
 #define CCXX_ENGINEWRITE_REF(valref) writeBinary((const uint8*)&valref,sizeof(valref))
-	void write(int8 i)   THROWS (Exception) { CCXX_ENGINEWRITE_REF(i); }
-	void write(uint8 i)  THROWS (Exception) { CCXX_ENGINEWRITE_REF(i); }
-	void write(int16 i)  THROWS (Exception) { CCXX_ENGINEWRITE_REF(i); }
-	void write(uint16 i) THROWS (Exception) { CCXX_ENGINEWRITE_REF(i); }
-	void write(int32 i)  THROWS (Exception) { CCXX_ENGINEWRITE_REF(i); }
-	void write(uint32 i) THROWS (Exception) { CCXX_ENGINEWRITE_REF(i); }
+	void write(int8 i)   THROWS (PersistException) { CCXX_ENGINEWRITE_REF(i); }
+	void write(uint8 i)  THROWS (PersistException) { CCXX_ENGINEWRITE_REF(i); }
+	void write(int16 i)  THROWS (PersistException) { CCXX_ENGINEWRITE_REF(i); }
+	void write(uint16 i) THROWS (PersistException) { CCXX_ENGINEWRITE_REF(i); }
+	void write(int32 i)  THROWS (PersistException) { CCXX_ENGINEWRITE_REF(i); }
+	void write(uint32 i) THROWS (PersistException) { CCXX_ENGINEWRITE_REF(i); }
 #ifdef	HAVE_64_BITS
-	void write(int64 i)  THROWS (Exception) { CCXX_ENGINEWRITE_REF(i); }
-	void write(uint64 i) THROWS (Exception) { CCXX_ENGINEWRITE_REF(i); }
+	void write(int64 i)  THROWS (PersistException) { CCXX_ENGINEWRITE_REF(i); }
+	void write(uint64 i) THROWS (PersistException) { CCXX_ENGINEWRITE_REF(i); }
 #endif
-	void write(float i)  THROWS (Exception) { CCXX_ENGINEWRITE_REF(i); }
-	void write(double i) THROWS (Exception) { CCXX_ENGINEWRITE_REF(i); }
+	void write(float i)  THROWS (PersistException) { CCXX_ENGINEWRITE_REF(i); }
+	void write(double i) THROWS (PersistException) { CCXX_ENGINEWRITE_REF(i); }
 #undef CCXX_ENGINEWRITE_REF
 
-	void write(const String& str) THROWS (Exception);
-	void write(const std::string& str) THROWS (Exception);
+	void write(const String& str) THROWS (PersistException);
+	void write(const std::string& str) THROWS (PersistException);
 
 	// Every write operation boils down to one or more of these
-	void writeBinary(const uint8* data, const uint32 size) THROWS (Exception);
+	void writeBinary(const uint8* data, const uint32 size) THROWS (PersistException);
 
 
 	// Read Operations
@@ -330,47 +318,47 @@ public:
  	/**
 	 * reads a BaseObject into a reference overwriting the object.
 	 */
-	void read(BaseObject &object) THROWS (Exception);
+	void read(BaseObject &object) THROWS (PersistException);
 
   /**
 	 * reads a BaseObject into a pointer allocating memory for the object if necessary.
 	 */
-	void read(BaseObject *&object) THROWS (Exception);
+	void read(BaseObject *&object) THROWS (PersistException);
 
 	// reads supported primitive types
   // shortcut, to make the following more readable
 #define CCXX_ENGINEREAD_REF(valref) readBinary((uint8*)&valref,sizeof(valref))
-	void read(int8& i)   THROWS (Exception) { CCXX_ENGINEREAD_REF(i); }
-	void read(uint8& i)  THROWS (Exception) { CCXX_ENGINEREAD_REF(i); }
-	void read(int16& i)  THROWS (Exception) { CCXX_ENGINEREAD_REF(i); }
-	void read(uint16& i) THROWS (Exception) { CCXX_ENGINEREAD_REF(i); }
-	void read(int32& i)  THROWS (Exception) { CCXX_ENGINEREAD_REF(i); }
-	void read(uint32& i) THROWS (Exception) { CCXX_ENGINEREAD_REF(i); }
+	void read(int8& i)   THROWS (PersistException) { CCXX_ENGINEREAD_REF(i); }
+	void read(uint8& i)  THROWS (PersistException) { CCXX_ENGINEREAD_REF(i); }
+	void read(int16& i)  THROWS (PersistException) { CCXX_ENGINEREAD_REF(i); }
+	void read(uint16& i) THROWS (PersistException) { CCXX_ENGINEREAD_REF(i); }
+	void read(int32& i)  THROWS (PersistException) { CCXX_ENGINEREAD_REF(i); }
+	void read(uint32& i) THROWS (PersistException) { CCXX_ENGINEREAD_REF(i); }
 #ifdef	HAVE_64_BITS
-	void read(int64& i)  THROWS (Exception) { CCXX_ENGINEREAD_REF(i); }
-	void read(uint64& i) THROWS (Exception) { CCXX_ENGINEREAD_REF(i); }
+	void read(int64& i)  THROWS (PersistException) { CCXX_ENGINEREAD_REF(i); }
+	void read(uint64& i) THROWS (PersistException) { CCXX_ENGINEREAD_REF(i); }
 #endif
-	void read(float& i)  THROWS (Exception) { CCXX_ENGINEREAD_REF(i); }
-	void read(double& i) THROWS (Exception) { CCXX_ENGINEREAD_REF(i); }
+	void read(float& i)  THROWS (PersistException) { CCXX_ENGINEREAD_REF(i); }
+	void read(double& i) THROWS (PersistException) { CCXX_ENGINEREAD_REF(i); }
 #undef CCXX_ENGINEREAD_REF
 
-	void read(String& str) THROWS (Exception);
-	void read(std::string& str) THROWS (Exception);
+	void read(String& str) THROWS (PersistException);
+	void read(std::string& str) THROWS (PersistException);
 
 	// Every read operation boild down to one or more of these
-	void readBinary(uint8* data, uint32 size) THROWS (Exception);
+	void readBinary(uint8* data, uint32 size) THROWS (PersistException);
 
 private:
   /**
    * reads the actual object data into a pre-instantiated object pointer
    * by calling the read function of the derived class.
    */
-  void readObject(BaseObject* object);
+  void readObject(BaseObject* object) THROWS (PersistException);
 
   /**
    * reads in a class name, and caches it into the ClassMap.
    */
-  const String readClass();
+  const String readClass() THROWS (PersistException);
 
 
 	/**
@@ -407,80 +395,80 @@ private:
 
 // Standard >> and << stream operators for BaseObject
 /** @relates Engine */
-__EXPORT Engine& operator >>( Engine& ar, BaseObject &ob)      THROWS (Engine::Exception);
+__EXPORT Engine& operator >>( Engine& ar, BaseObject &ob)      THROWS (PersistException);
 /** @relates Engine */
-__EXPORT Engine& operator >>( Engine& ar, BaseObject *&ob)      THROWS (Engine::Exception);
+__EXPORT Engine& operator >>( Engine& ar, BaseObject *&ob)      THROWS (PersistException);
 /** @relates Engine */
-__EXPORT Engine& operator <<( Engine& ar, BaseObject const &ob) THROWS (Engine::Exception);
+__EXPORT Engine& operator <<( Engine& ar, BaseObject const &ob) THROWS (PersistException);
 /** @relates Engine */
-__EXPORT Engine& operator <<( Engine& ar, BaseObject const *ob) THROWS (Engine::Exception);
+__EXPORT Engine& operator <<( Engine& ar, BaseObject const *ob) THROWS (PersistException);
 
 /** @relates Engine */
-__EXPORT Engine& operator >>( Engine& ar, int8& ob) THROWS (Engine::Exception);
+__EXPORT Engine& operator >>( Engine& ar, int8& ob) THROWS (PersistException);
 /** @relates Engine */
-__EXPORT Engine& operator <<( Engine& ar, int8 ob)  THROWS (Engine::Exception);
+__EXPORT Engine& operator <<( Engine& ar, int8 ob)  THROWS (PersistException);
 
 /** @relates Engine */
-__EXPORT Engine& operator >>( Engine& ar, uint8& ob) THROWS (Engine::Exception);
+__EXPORT Engine& operator >>( Engine& ar, uint8& ob) THROWS (PersistException);
 /** @relates Engine */
-__EXPORT Engine& operator <<( Engine& ar, uint8 ob)  THROWS (Engine::Exception);
+__EXPORT Engine& operator <<( Engine& ar, uint8 ob)  THROWS (PersistException);
 
 /** @relates Engine */
-__EXPORT Engine& operator >>( Engine& ar, int16& ob) THROWS (Engine::Exception);
+__EXPORT Engine& operator >>( Engine& ar, int16& ob) THROWS (PersistException);
 /** @relates Engine */
-__EXPORT Engine& operator <<( Engine& ar, int16 ob)  THROWS (Engine::Exception);
+__EXPORT Engine& operator <<( Engine& ar, int16 ob)  THROWS (PersistException);
 
 /** @relates Engine */
-__EXPORT Engine& operator >>( Engine& ar, uint16& ob) THROWS (Engine::Exception);
+__EXPORT Engine& operator >>( Engine& ar, uint16& ob) THROWS (PersistException);
 /** @relates Engine */
-__EXPORT Engine& operator <<( Engine& ar, uint16 ob)  THROWS (Engine::Exception);
+__EXPORT Engine& operator <<( Engine& ar, uint16 ob)  THROWS (PersistException);
 
 /** @relates Engine */
-__EXPORT Engine& operator >>( Engine& ar, int32& ob) THROWS (Engine::Exception);
+__EXPORT Engine& operator >>( Engine& ar, int32& ob) THROWS (PersistException);
 /** @relates Engine */
-__EXPORT Engine& operator <<( Engine& ar, int32 ob)  THROWS (Engine::Exception);
+__EXPORT Engine& operator <<( Engine& ar, int32 ob)  THROWS (PersistException);
 
 /** @relates Engine */
-__EXPORT Engine& operator >>( Engine& ar, uint32& ob) THROWS (Engine::Exception);
+__EXPORT Engine& operator >>( Engine& ar, uint32& ob) THROWS (PersistException);
 /** @relates Engine */
-__EXPORT Engine& operator <<( Engine& ar, uint32 ob)  THROWS (Engine::Exception);
+__EXPORT Engine& operator <<( Engine& ar, uint32 ob)  THROWS (PersistException);
 
 #ifdef	HAVE_64_BITS
 /** @relates Engine */
-__EXPORT Engine& operator >>( Engine& ar, int64& ob) THROWS (Engine::Exception);
+__EXPORT Engine& operator >>( Engine& ar, int64& ob) THROWS (PersistException);
 /** @relates Engine */
-__EXPORT Engine& operator <<( Engine& ar, int64 ob)  THROWS (Engine::Exception);
+__EXPORT Engine& operator <<( Engine& ar, int64 ob)  THROWS (PersistException);
 
 /** @relates Engine */
-__EXPORT Engine& operator >>( Engine& ar, uint64& ob) THROWS (Engine::Exception);
+__EXPORT Engine& operator >>( Engine& ar, uint64& ob) THROWS (PersistException);
 /** @relates Engine */
-__EXPORT Engine& operator <<( Engine& ar, uint64 ob)  THROWS (Engine::Exception);
+__EXPORT Engine& operator <<( Engine& ar, uint64 ob)  THROWS (PersistException);
 #endif
 
 /** @relates Engine */
-__EXPORT Engine& operator >>( Engine& ar, float& ob) THROWS (Engine::Exception);
+__EXPORT Engine& operator >>( Engine& ar, float& ob) THROWS (PersistException);
 /** @relates Engine */
-__EXPORT Engine& operator <<( Engine& ar, float ob)  THROWS (Engine::Exception);
+__EXPORT Engine& operator <<( Engine& ar, float ob)  THROWS (PersistException);
 
 /** @relates Engine */
-__EXPORT Engine& operator >>( Engine& ar, double& ob) THROWS (Engine::Exception);
+__EXPORT Engine& operator >>( Engine& ar, double& ob) THROWS (PersistException);
 /** @relates Engine */
-__EXPORT Engine& operator <<( Engine& ar, double ob)  THROWS (Engine::Exception);
+__EXPORT Engine& operator <<( Engine& ar, double ob)  THROWS (PersistException);
 
 /** @relates Engine */
-__EXPORT Engine& operator >>( Engine& ar, String& ob) THROWS (Engine::Exception);
+__EXPORT Engine& operator >>( Engine& ar, String& ob) THROWS (PersistException);
 /** @relates Engine */
-__EXPORT Engine& operator <<( Engine& ar, String ob)  THROWS (Engine::Exception);
+__EXPORT Engine& operator <<( Engine& ar, String ob)  THROWS (PersistException);
 
 /** @relates Engine */
-__EXPORT Engine& operator >>( Engine& ar, std::string& ob) THROWS (Engine::Exception);
+__EXPORT Engine& operator >>( Engine& ar, std::string& ob) THROWS (PersistException);
 /** @relates Engine */
-__EXPORT Engine& operator <<( Engine& ar, std::string ob)  THROWS (Engine::Exception);
+__EXPORT Engine& operator <<( Engine& ar, std::string ob)  THROWS (PersistException);
 
 /** @relates Engine */
-__EXPORT Engine& operator >>( Engine& ar, bool& ob) THROWS (Engine::Exception);
+__EXPORT Engine& operator >>( Engine& ar, bool& ob) THROWS (PersistException);
 /** @relates Engine */
-__EXPORT Engine& operator <<( Engine& ar, bool ob)  THROWS (Engine::Exception);
+__EXPORT Engine& operator <<( Engine& ar, bool ob)  THROWS (PersistException);
 
 /**
  * The following are templated classes
@@ -492,7 +480,7 @@ __EXPORT Engine& operator <<( Engine& ar, bool ob)  THROWS (Engine::Exception);
  * the engine
  */
 template<class T>
-Engine& operator <<( Engine& ar, typename std::vector<T> const& ob) THROWS (Engine::Exception)
+Engine& operator <<( Engine& ar, typename std::vector<T> const& ob) THROWS (PersistException)
 {
 	ar << (uint32)ob.size();
 	for(unsigned int i=0; i < ob.size(); ++i)
@@ -506,7 +494,7 @@ Engine& operator <<( Engine& ar, typename std::vector<T> const& ob) THROWS (Engi
  * an engine.
  */
 template<class T>
-Engine& operator >>( Engine& ar, typename std::vector<T>& ob) THROWS (Engine::Exception)
+Engine& operator >>( Engine& ar, typename std::vector<T>& ob) THROWS (PersistException)
 {
 	ob.clear();
 	uint32 siz;
@@ -523,7 +511,7 @@ Engine& operator >>( Engine& ar, typename std::vector<T>& ob) THROWS (Engine::Ex
  * the engine
  */
 template<class T>
-Engine& operator <<( Engine& ar, typename std::deque<T> const& ob) THROWS (Engine::Exception)
+Engine& operator <<( Engine& ar, typename std::deque<T> const& ob) THROWS (PersistException)
 {
 	ar << (uint32)ob.size();
   for(typename std::deque<T>::const_iterator it=ob.begin(); it != ob.end(); ++it)
@@ -537,7 +525,7 @@ Engine& operator <<( Engine& ar, typename std::deque<T> const& ob) THROWS (Engin
  * an engine.
  */
 template<class T>
-Engine& operator >>( Engine& ar, typename std::deque<T>& ob) THROWS (Engine::Exception)
+Engine& operator >>( Engine& ar, typename std::deque<T>& ob) THROWS (PersistException)
 {
 	ob.clear();
 	uint32 siz;
@@ -559,7 +547,7 @@ Engine& operator >>( Engine& ar, typename std::deque<T>& ob) THROWS (Engine::Exc
  * to an engine.
  */
 template<class Key, class Value>
-Engine& operator <<( Engine& ar, typename std::map<Key,Value> const & ob) THROWS (Engine::Exception)
+Engine& operator <<( Engine& ar, typename std::map<Key,Value> const & ob) THROWS (PersistException)
 {
 	ar << (uint32)ob.size();
 	for(typename std::map<Key,Value>::const_iterator it = ob.begin();it != ob.end();++it)
@@ -573,7 +561,7 @@ Engine& operator <<( Engine& ar, typename std::map<Key,Value> const & ob) THROWS
  * from an engine.
  */
 template<class Key, class Value>
-Engine& operator >>( Engine& ar, typename std::map<Key,Value>& ob) THROWS (Engine::Exception)
+Engine& operator >>( Engine& ar, typename std::map<Key,Value>& ob) THROWS (PersistException)
 {
 	ob.clear();
 	uint32 siz;
@@ -591,7 +579,7 @@ Engine& operator >>( Engine& ar, typename std::map<Key,Value>& ob) THROWS (Engin
  * serialize a pair of some serializable content to the engine.
  */
 template<class x, class y>
-Engine& operator <<( Engine& ar, std::pair<x,y> &ob) THROWS (Engine::Exception)
+Engine& operator <<( Engine& ar, std::pair<x,y> &ob) THROWS (PersistException)
 {
 	ar << ob.first << ob.second;
 	return ar;
@@ -602,7 +590,7 @@ Engine& operator <<( Engine& ar, std::pair<x,y> &ob) THROWS (Engine::Exception)
  * deserialize a pair of some serializable content to the engine.
  */
 template<class x, class y>
-Engine& operator >>(Engine& ar, std::pair<x, y> &ob) THROWS (Engine::Exception)
+Engine& operator >>(Engine& ar, std::pair<x, y> &ob) THROWS (PersistException)
 {
 	ar >> ob.first >> ob.second;
 	return ar;
