@@ -74,7 +74,7 @@ timespec *getTimeout(struct timespec *spec, timeout_t timer)
 
 	offset.tv_sec = timer / 1000;
 	offset.tv_nsec = (timer % 1000) * 1000000;
-	pthread_get_expiration_np(&offset, sec);
+	pthread_get_expiration_np(&offset, spec);
 #else
 	struct timeval current;
 
