@@ -701,7 +701,7 @@ void XMLRPC::begStruct(void)
 	if(!fault && !array)
 		strBuf << "<param>";
 
-	strBuf << "<struct><value>" << endl;
+	strBuf << "<value><struct>" << endl;
 }
 
 void XMLRPC::endStruct(void)
@@ -734,6 +734,8 @@ bool XMLRPC::send(const char *resource)
 	}
 	if(!fault)
 		strBuf << "</params>" << endl;
+	else
+		strBuf << "</fault>" << endl;
 
 	if(reply)
 		strBuf << "</methodResponse>" << endl << ends;
