@@ -38,12 +38,26 @@
 // whether to permit this exception to apply to your modifications.
 // If you do not wish that, delete this exception notice.  
 
+/**
+ * @file objlink.h
+ * @short Template for creating linked list of objects with lookup.
+ **/
+
+
 #include <cstddef>
 
 namespace ost {
 
+/**
+ * Used to create and manage a single linked list of objects of a common
+ * type.  The list of created objects can be examined to find a key by 
+ * an identifier.
+ *
+ * @author David Sugar <dyfet@gnutelephony.org>
+ * @short single linked list searchable template chain.
+ */
 template <class T, typename K>
-class objList {
+class __EXPORT objList {
 protected:
 	static T* objFirst;
 	T* objNext;
@@ -60,10 +74,10 @@ public:
 };
 
 template <class T, typename K>
-T *objList<T, K>::objFirst = NULL;
+__EXPORT T *objList<T, K>::objFirst = NULL;
 
 template <class T, typename K>
-T *objList<T, K>::getObject(const K& key)
+__EXPORT T *objList<T, K>::getObject(const K& key)
 {
 	T *obj = objList<T, K>::objFirst;
 	while(obj)
